@@ -11,10 +11,10 @@
 #include <tqlabel.h>
 #include <tqdatetime.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
 #include <kpushbutton.h>
-//#include <kmessagebox.h>
+//#include <tdemessagebox.h>
 #include <klineedit.h>
 #include <kcombobox.h>
 #include <knuminput.h>
@@ -41,18 +41,18 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
     tagEngine = _tagEngine;
 
     // create an icon loader object for loading icons
-    KIconLoader* iconLoader = new KIconLoader();
+    TDEIconLoader* iconLoader = new TDEIconLoader();
 
     resize( 400, 350 );
     // TODO move the dialog beside the main window
-    setIcon( iconLoader->loadIcon("view_text",KIcon::Small) );
+    setIcon( iconLoader->loadIcon("view_text",TDEIcon::Small) );
 
-//     setButtonGuiItem( User2, KGuiItem(i18n("Previous"),iconLoader->loadIconSet("previous",KIcon::Small,16,true/*KDE3.5,false*/)) );
-//     setButtonGuiItem( User1, KGuiItem(i18n("Next"),iconLoader->loadIconSet("next",KIcon::Small,16,true/*KDE3.5,false*/)) );
-    setButtonGuiItem( Ok, KGuiItem(i18n("Close"),iconLoader->loadIconSet("exit",KIcon::Small,16,true/*KDE3.5,false*/)) );
+//     setButtonGuiItem( User2, KGuiItem(i18n("Previous"),iconLoader->loadIconSet("go-previous",TDEIcon::Small,16,true/*KDE3.5,false*/)) );
+//     setButtonGuiItem( User1, KGuiItem(i18n("Next"),iconLoader->loadIconSet("go-next",TDEIcon::Small,16,true/*KDE3.5,false*/)) );
+    setButtonGuiItem( Ok, KGuiItem(i18n("Close"),iconLoader->loadIconSet("system-log-out",TDEIcon::Small,16,true/*KDE3.5,false*/)) );
 
     //// options page ////
-    conversionOptions = addPage( i18n("Conversion"), i18n("Conversion options"), iconLoader->loadIcon("soundkonverter",KIcon::Desktop) );
+    conversionOptions = addPage( i18n("Conversion"), i18n("Conversion options"), iconLoader->loadIcon("soundkonverter",TDEIcon::Desktop) );
     // the grid for all widgets in the main window
     TQGridLayout* conversionOptionsGridLayout = new TQGridLayout( conversionOptions, 1, 1, 0, 6, "conversionOptionsGridLayout" );
     // generate the options input area
@@ -76,7 +76,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
              );
 
     //// tags page ////
-    tags = addPage( i18n("Tags"), i18n("Tags"), iconLoader->loadIcon("view_text",KIcon::Desktop) );
+    tags = addPage( i18n("Tags"), i18n("Tags"), iconLoader->loadIcon("view_text",TDEIcon::Desktop) );
     // the grid for all widgets in the main window
     TQGridLayout* tagsGridLayout = new TQGridLayout( tags, 1, 1, 0, 6, "tagsGridLayout" );
 
@@ -93,7 +93,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
                this, TQT_SLOT(titleChanged(const TQString&))
              );
     pTitleEdit = new KPushButton( " ", tags, "pTitleEdit" );
-    pTitleEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pTitleEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pTitleEdit->setFixedSize( lTitle->sizeHint().height(), lTitle->sizeHint().height() );
     pTitleEdit->hide();
     titleBox->addWidget( pTitleEdit );
@@ -108,7 +108,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
                this, TQT_SLOT(numberChanged(int))
              );
     pNumberEdit = new KPushButton( " ", tags, "pNumberEdit" );
-    pNumberEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pNumberEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pNumberEdit->setFixedSize( iNumber->sizeHint().height(), iNumber->sizeHint().height() );
     pNumberEdit->hide();
     titleBox->addWidget( pNumberEdit );
@@ -128,7 +128,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
                this, TQT_SLOT(artistChanged(const TQString&))
              );
     pArtistEdit = new KPushButton( " ", tags, "pArtistEdit" );
-    pArtistEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pArtistEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pArtistEdit->setFixedSize( lArtist->sizeHint().height(), lArtist->sizeHint().height() );
     pArtistEdit->hide();
     artistBox->addWidget( pArtistEdit );
@@ -143,7 +143,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
                this, TQT_SLOT(composerChanged(const TQString&))
              );
     pComposerEdit = new KPushButton( " ", tags, "pComposerEdit" );
-    pComposerEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pComposerEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pComposerEdit->setFixedSize( lComposer->sizeHint().height(), lComposer->sizeHint().height() );
     pComposerEdit->hide();
     artistBox->addWidget( pComposerEdit );
@@ -163,7 +163,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
                this, TQT_SLOT(albumChanged(const TQString&))
              );
     pAlbumEdit = new KPushButton( " ", tags, "pAlbumEdit" );
-    pAlbumEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pAlbumEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pAlbumEdit->setFixedSize( lAlbum->sizeHint().height(), lAlbum->sizeHint().height() );
     pAlbumEdit->hide();
     albumBox->addWidget( pAlbumEdit );
@@ -183,7 +183,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
                this, TQT_SLOT(discChanged(int))
              );
     pDiscEdit = new KPushButton( " ", tags, "pDiscEdit" );
-    pDiscEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pDiscEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pDiscEdit->setFixedSize( iDisc->sizeHint().height(), iDisc->sizeHint().height() );
     pDiscEdit->hide();
     albumdataBox->addWidget( pDiscEdit );
@@ -199,7 +199,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
                this, TQT_SLOT(yearChanged(int))
              );
     pYearEdit = new KPushButton( " ", tags, "pYearEdit" );
-    pYearEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pYearEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pYearEdit->setFixedSize( iYear->sizeHint().height(), iYear->sizeHint().height() );
     pYearEdit->hide();
     albumdataBox->addWidget( pYearEdit );
@@ -212,7 +212,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
     cGenre = new KComboBox( true, tags, "cGenre" );
     cGenre->insertStringList( tagEngine->genreList );
     cGenre->setCurrentText( "" );
-    KCompletion *cGenreCompletion = cGenre->completionObject();
+    TDECompletion *cGenreCompletion = cGenre->completionObject();
     cGenreCompletion->insertItems( tagEngine->genreList );
     cGenreCompletion->setIgnoreCase( tags );
     albumdataBox->addWidget( cGenre );
@@ -220,7 +220,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
                this, TQT_SLOT(genreChanged(const TQString&))
              );
     pGenreEdit = new KPushButton( " ", tags, "pGenreEdit" );
-    pGenreEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pGenreEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pGenreEdit->setFixedSize( cGenre->sizeHint().height(), cGenre->sizeHint().height() );
     pGenreEdit->hide();
     albumdataBox->addWidget( pGenreEdit );
@@ -240,7 +240,7 @@ OptionsEditor::OptionsEditor( TagEngine* _tagEngine, Config* _config, FileList*
                this, TQT_SLOT(commentChanged())
              );
     pCommentEdit = new KPushButton( " ", tags, "pCommentEdit" );
-    pCommentEdit->setPixmap( iconLoader->loadIcon("kwrite",KIcon::Small) );
+    pCommentEdit->setPixmap( iconLoader->loadIcon("kwrite",TDEIcon::Small) );
     pCommentEdit->setFixedSize( lTitle->sizeHint().height(), lTitle->sizeHint().height() );
     pCommentEdit->hide();
     commentBox->addWidget( pCommentEdit );
